@@ -6,18 +6,13 @@ use std::io::{BufRead, Write};
 #[cfg(target_os = "wasi")]
 mod wasi {
     use std::io::{self, BufRead};
-    use crate::rutil::print_tty::{print_tty};
 
     /// Reads a password from the TTY
     pub fn read_password() -> std::io::Result<String> {
-        let ret = {
-            let tty = std::fs::File::open("/dev/tty")?;
-            let mut reader = io::BufReader::new(tty);
+        let tty = std::fs::File::open("/dev/tty")?;
+        let mut reader = io::BufReader::new(tty);
 
-            read_password_from_fd_with_hidden_input(&mut reader)
-        };
-        print_tty("\n");
-        ret
+        read_password_from_fd_with_hidden_input(&mut reader)
     }
 
     /// Reads a password from a given file descriptor
@@ -231,7 +226,11 @@ pub fn prompt_password_from_bufread(
 
 /// Prompts on the TTY and then reads a password from stdin
 pub fn prompt_password(prompt: impl ToString) -> std::io::Result<String> {
-    print_tty(prompt.to_string().as_str()).and_then(|_| read_password())
+    let ret = print_tty(prompt.to_string().as_str())
+        .and_then(|_| read_password());
+    #[cfg(target_os = "wasi")]
+    let _ = print_tty("\n");
+    ret
 }
 
 #[cfg(test)]
